aboutsummaryrefslogtreecommitdiff
path: root/module/vcomponent
diff options
context:
space:
mode:
Diffstat (limited to 'module/vcomponent')
-rw-r--r--module/vcomponent/parse.scm4
-rw-r--r--module/vcomponent/parse/ical.scm (renamed from module/vcomponent/parse/component.scm)4
2 files changed, 3 insertions, 5 deletions
diff --git a/module/vcomponent/parse/component.scm b/module/vcomponent/parse/ical.scm
index 41ef30f5..a07487f0 100644
--- a/module/vcomponent/parse/component.scm
+++ b/module/vcomponent/parse/ical.scm
@@ -1,6 +1,4 @@
-;;; TODO rename to (vcomponent parse ical)? To work nices alongside
-;;; (vcomponent parse xcal)
-(define-module (vcomponent parse component)
+(define-module (vcomponent parse ical)
:use-module (util)
:use-module (util exceptions)
:use-module ((ice-9 rdelim) :select (read-line))
diff --git a/module/vcomponent/parse.scm b/module/vcomponent/parse.scm
index 7b2d7fc5..0b5f5529 100644
--- a/module/vcomponent/parse.scm
+++ b/module/vcomponent/parse.scm
@@ -1,7 +1,7 @@
;;; Commentary:
;; Code for parsing vdir's and icalendar files.
;; This module handles the finding of files, while
;; (vcomponent parse component) handles reading data from icalendar files.
;;; Code:
(define-module (vcomponent parse)
@@ -17,7 +17,7 @@
:use-module (util exceptions)
:use-module (vcomponent base)
- :use-module (vcomponent parse component)
+ :use-module (vcomponent parse ical)
:re-export (parse-calendar)
)
@@ -1,7 +1,7 @@
;; Code for parsing vdir's and icalendar files.
;; This module handles the finding of files, while
-;; (vcomponent parse component) handles reading data from icalendar files.
+;; (vcomponent parse ical) handles reading data from icalendar files.
;;; Code:
(define-module (vcomponent parse)